@@ -5,7 +5,45 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef MDEBUG
+#ifndef MDEBUG
+
+ALLOC void* xmalloc(size_t size)
+{
+    void* buf = malloc(size);
+
+    if(buf == NULL) {
+        fprintf(stderr, "It is not enough memory");
+        exit(1);
+    }
+
+    return buf;
+}
+
+ALLOC char* xstrdup(char* str)
+{
+    char* buf = strdup(str);
+
+    if(buf == NULL) {
+        fprintf(stderr, "It is not enough memory\n");
+        exit(1);
+    }
+
+    return buf;
+}
+
+ALLOC void* xrealloc(void* ptr, size_t size)
+{
+    char* buf = realloc(ptr, size);
+
+    if(buf == NULL) {
+        fprintf(stderr, "It is not enough memory\n");
+        exit(1);
+    }
+
+    return buf;
+}
+
+#else
 
 static char* xstrncpy(char* des, char* src, int size)
 {
