@@ -1,5 +1,5 @@
 #include "config.h"
-#include "xyzsh/xyzsh.h"
+#include "xyzsh.h"
 #include <string.h>
 #include <stdio.h>
 
@@ -104,12 +104,11 @@ sObject* uobject_new_from_stack(int size, sObject* parent, char* name)
    return self;
 }
 
-sObject* gInheritMethod;
-
-void uobject_root_init(sObject* self)
+void xyzsh_object_init(sObject* self)
 {
     ASSERT(STYPE(self) == T_UOBJECT);
 
+    uobject_put(self, "typeof", NFUN_NEW_GC(cmd_typeof, NULL, TRUE));
     uobject_put(self, "unset", NFUN_NEW_GC(cmd_unset, NULL, TRUE));
     uobject_put(self, "completion", NFUN_NEW_GC(cmd_completion, NULL, TRUE));
     uobject_put(self, "p", NFUN_NEW_GC(cmd_p, NULL, TRUE));
@@ -135,12 +134,10 @@ void uobject_root_init(sObject* self)
     uobject_put(self, "quote", NFUN_NEW_GC(cmd_quote, NULL, TRUE));
     uobject_put(self, "load", NFUN_NEW_GC(cmd_load, NULL, TRUE));
     uobject_put(self, "combine", NFUN_NEW_GC(cmd_combine, NULL, TRUE));
-    gInheritMethod = NFUN_NEW_GC(cmd_inherit, NULL, TRUE);
-    uobject_put(self, "inherit", gInheritMethod);
+    uobject_put(self, "inherit", NFUN_NEW_GC(cmd_inherit, NULL, TRUE));
     uobject_put(self, "eval", NFUN_NEW_GC(cmd_eval, NULL, TRUE));
     uobject_put(self, "object", NFUN_NEW_GC(cmd_object, NULL, TRUE));
     uobject_put(self, "pwo", NFUN_NEW_GC(cmd_pwo, NULL, TRUE));
-    uobject_put(self, "co", NFUN_NEW_GC(cmd_co, NULL, TRUE));
     uobject_put(self, "ref", NFUN_NEW_GC(cmd_ref, NULL, TRUE));
     uobject_put(self, "length", NFUN_NEW_GC(cmd_length, NULL, TRUE));
     uobject_put(self, "export", NFUN_NEW_GC(cmd_export, NULL, TRUE));
@@ -170,6 +167,7 @@ void uobject_root_init(sObject* self)
     uobject_put(self, "rows", NFUN_NEW_GC(cmd_rows, NULL, TRUE));
     uobject_put(self, "scan", NFUN_NEW_GC(cmd_scan, NULL, TRUE));
     uobject_put(self, "expand_tilda", NFUN_NEW_GC(cmd_expand_tilda, NULL, TRUE));
+    uobject_put(self, "alias", NFUN_NEW_GC(cmd_alias, NULL, TRUE));
 
     sObject* nfun = NFUN_NEW_GC(cmd_split, NULL, TRUE);
     (void)nfun_put_option_with_argument(nfun, STRDUP("-target"));
@@ -283,7 +281,14 @@ void uobject_root_init(sObject* self)
     nfun = NFUN_NEW_GC(cmd_class, NULL, TRUE);
     (void)nfun_put_option_with_argument(nfun, STRDUP("-option-with-argument"));
     uobject_put(self, "class", nfun);
+}
 
+sObject* gInheritMethod;
+
+void uobject_root_init(sObject* self)
+{
+    xyzsh_object_init(self);
+    gInheritMethod = uobject_item(self, "inherit");
     editline_object_init(self);
     curses_object_init(self);
 
